/**
 * The error code when a user hits Ctrl-C
 */
export declare const USER_INTERRUPTED_CODE = "UserInterrupted";
/**
 * If we can't find a specific error code
 */
export declare const UNKNOWN_ERROR_CODE = "UnknownError";
/**
 * Return the transmitted error code for this error object
 *
 * We are taking care to only transmit errors that originate from AWS systems
 * (this toolkit itself, the CDK construct library, the AWS SDK, AWS services).
 */
export declare function cdkCliErrorName(err: Error): string;
