export declare const JS_PACKAGE_MANAGERS: readonly [{
    readonly name: "npm";
    readonly commandPrefix: "npm run";
}, {
    readonly name: "yarn";
    readonly commandPrefix: "yarn";
}, {
    readonly name: "pnpm";
    readonly commandPrefix: "pnpm";
}, {
    readonly name: "bun";
    readonly commandPrefix: "bun run";
}];
export type JsPackageManager = (typeof JS_PACKAGE_MANAGERS)[number]['name'];
export declare const getPmCmdPrefix: (packageManager: JsPackageManager) => string;
