import type { IoHelper } from '../../api-private';
/**
 * Get or create installation id
 */
export declare function getOrCreateInstallationId(ioHelper: IoHelper): Promise<string>;
/**
 * Make sure the cache dir exists
 *
 * Not part of `directories.ts` because that module is mocked in tests in order to mock the temporary directory
 * to write to, and then I need to mock this function as well.
 */
export declare function ensureCacheDir(): Promise<void>;
