/**
 * Telemetry state across CLI invocations
 */
export interface TelemetryState {
    /**
     * How many deployment failures we've seen since the last success.
     */
    sequentialDeploymentFailures?: number;
}
/**
 * Run a function that can modify the given telemetry state.
 */
export declare function withTelemetryState<A>(block: (x: TelemetryState) => A): Promise<A>;
/**
 * Load telemetry state
 */
export declare function loadTelemetryState(): Promise<TelemetryState>;
export declare function writeTelemetryState(state: TelemetryState): Promise<void>;
