using Amazon.CDK;
using Constructs;

namespace %name.PascalCased%
{
    public class %name.PascalCased%Stack : Stack
    {
        internal %name.PascalCased%Stack(Construct scope, string id, IStackProps props = null) : base(scope, id, props)
        {
            // The code that defines your stack goes here
        }
    }
}
