import type { Settings } from '../api/settings';
import type { IoHelper } from '../api-private';
export interface DoctorOptions {
    readonly ioHelper: IoHelper;
    /**
     * The resolved CLI settings, used to report the active CLI configuration
     * (debug targets, verbosity, ...).
     *
     * @default - configuration is not reported
     */
    readonly settings?: Settings;
}
export declare function doctor({ ioHelper, settings }: DoctorOptions): Promise<number>;
